# Usage Guide: pdfalive

`pdfalive` is a Python package which comes with a command-line interface exposing various sub-commands.


## Basic Usage

You can install the package using pip, e.g.:

	pip install pdfalive
	pdfalive --help

Alternatively you can simply invoke it directly using uvx (assuming you have [uv](https://docs.astral.sh/uv/) installed):

	uvx pdfalive --help
